@@ -23,6 +23,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
+#include <string.h>
+#include <locale.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -52,6 +54,8 @@ static DBusHandlerResult dbus_filter_func         (DBusConnection *connection,
 						   void           *data);
 
 
+static gboolean replace_daemon = FALSE;
+
 static DBusObjectPathVTable daemon_vtable = {
 	daemon_unregistered_func,
 	daemon_message_func,
@@ -83,6 +87,7 @@ daemon_get_connection (gboolean create)
 	static DBusConnection *conn = NULL;
 	DBusError              error;
 	gint                   ret;
+	int flags;
 
 	if (conn) {
 		return conn;
@@ -103,12 +108,16 @@ daemon_get_connection (gboolean create)
 		return NULL;
 	}
 
-	ret = dbus_bus_request_name (conn, DVD_DAEMON_SERVICE, 0, &error);
+	flags = DBUS_NAME_FLAG_ALLOW_REPLACEMENT;
+	if (replace_daemon) {
+		flags |= DBUS_NAME_FLAG_REPLACE_EXISTING;
+	}
+	ret = dbus_bus_request_name (conn, DVD_DAEMON_SERVICE, flags, &error);
 	if (dbus_error_is_set (&error)) {
 		g_warning ("Failed to acquire vfs-daemon service: %s", error.message);
 		dbus_error_free (&error);
 
-		dbus_connection_disconnect (conn);
+		dbus_connection_close (conn);
 		/* Remove this, it asserts:
 		   dbus_connection_unref (conn); */
 		conn = NULL;
@@ -119,7 +128,7 @@ daemon_get_connection (gboolean create)
 	if (ret == DBUS_REQUEST_NAME_REPLY_EXISTS) {
 		g_printerr ("VFS daemon already running, exiting.\n");
 
-		dbus_connection_disconnect (conn);
+		dbus_connection_close (conn);
 		/* Remove this, it asserts:
 		   dbus_connection_unref (conn); */
 		conn = NULL;
@@ -130,7 +139,7 @@ daemon_get_connection (gboolean create)
 	if (ret != DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER) {
 		g_printerr ("Not primary owner of the service, exiting.\n");
 
-		dbus_connection_disconnect (conn);
+		dbus_connection_close (conn);
 		/* Remove this, it asserts:
 		   dbus_connection_unref (conn); */
 		conn = NULL;
@@ -149,7 +158,7 @@ daemon_get_connection (gboolean create)
 						   NULL)) {
 		g_printerr ("Failed to register object with D-BUS.\n");
 
-		dbus_connection_disconnect (conn);
+		dbus_connection_close (conn);
 		dbus_connection_unref (conn);
 		conn = NULL;
 
@@ -177,7 +186,7 @@ daemon_shutdown (void)
 		return;
 	}
 
-	dbus_connection_disconnect (conn);
+	dbus_connection_close (conn);
 	dbus_connection_unref (conn);
 }
 
@@ -901,9 +910,20 @@ main (int argc, char *argv[])
 {
 	GMainLoop             *loop;
 	GnomeVFSVolumeMonitor *monitor;
+	int i;
 
 	d(g_print ("Starting daemon.\n"));
 
+	if (argc > 1) {
+		for (i = 1; i < argc; i++) {
+			if (strcmp (argv[i], "--replace") == 0) {
+				replace_daemon = TRUE;
+			}
+		}
+	}
+
+	setlocale(LC_ALL, "");
+	
 	g_type_init ();
 
 	gnome_vfs_set_is_daemon (GNOME_VFS_TYPE_VOLUME_MONITOR_DAEMON,
